@@ -47,7 +47,7 @@ void CollectionIndexingJob::start()
 void CollectionIndexingJob::slotOnCollectionFetched(KJob *job)
 {
     if (job->error()) {
-        qCWarning(AKONADI_INDEXER_AGENT_LOG) << "Failed to fetch items: " << job->errorString();
+        qCWarning(AKONADI_INDEXER_AGENT_LOG) << "Failed to fetch items:" << job->errorString();
         setError(KJob::UserDefinedError);
         emitResult();
         return;
@@ -70,7 +70,7 @@ void CollectionIndexingJob::slotOnCollectionFetched(KJob *job)
 
     if (m_pending.isEmpty()) {
         if (!m_fullSync) {
-            qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Indexing complete. Total time: " << m_time.elapsed();
+            qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Indexing complete. Total time:" << m_time.elapsed();
             emitResult();
             return;
         }
@@ -82,7 +82,7 @@ void CollectionIndexingJob::slotOnCollectionFetched(KJob *job)
 
 void CollectionIndexingJob::indexItems(const QList<Akonadi::Item::Id> &itemIds)
 {
-    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "collectionIndexingJob::indexItems(const QList<Akonadi::Item::Id> &itemIds) count " << itemIds.count();
+    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "collectionIndexingJob::indexItems(const QList<Akonadi::Item::Id> &itemIds) count:" << itemIds.count();
     Akonadi::Item::List items;
     items.reserve(itemIds.size());
     for (const Akonadi::Item::Id id : itemIds) {
@@ -109,9 +109,9 @@ void CollectionIndexingJob::indexItems(const QList<Akonadi::Item::Id> &itemIds)
 
 void CollectionIndexingJob::slotPendingItemsReceived(const Akonadi::Item::List &items)
 {
-    qCDebug(AKONADI_INDEXER_AGENT_LOG) << " CollectionIndexingJob::slotPendingItemsReceived " << items.count();
+    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "CollectionIndexingJob::slotPendingItemsReceived" << items.count();
     for (const Akonadi::Item &item : items) {
-        qCDebug(AKONADI_INDEXER_AGENT_LOG) << " void CollectionIndexingJob::slotPendingItemsReceived(const Akonadi::Item::List &items)" << item.id();
+        qCDebug(AKONADI_INDEXER_AGENT_LOG) << "void CollectionIndexingJob::slotPendingItemsReceived(const Akonadi::Item::List &items)" << item.id();
         m_index.index(item);
     }
     m_progressCounter++;
@@ -120,19 +120,19 @@ void CollectionIndexingJob::slotPendingItemsReceived(const Akonadi::Item::List &
 
 void CollectionIndexingJob::slotPendingIndexed(KJob *job)
 {
-    qCDebug(AKONADI_INDEXER_AGENT_LOG) << " CollectionIndexingJob::slotPendingIndexed ";
+    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "CollectionIndexingJob::slotPendingIndexed";
     if (job->error()) {
-        qCWarning(AKONADI_INDEXER_AGENT_LOG) << "Failed to fetch items: " << job->errorString();
+        qCWarning(AKONADI_INDEXER_AGENT_LOG) << "Failed to fetch items:" << job->errorString();
         setError(KJob::UserDefinedError);
         emitResult();
         return;
     }
-    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Indexed " << job->property("count").toInt()
-                                       << " items in (ms): " << m_time.elapsed() - job->property("start").toInt();
+    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Indexed" << job->property("count").toInt() //
+                                       << "items in (ms):" << m_time.elapsed() - job->property("start").toInt();
 
     if (!m_fullSync) {
         m_index.scheduleCommit();
-        qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Indexing complete. Total time: " << m_time.elapsed();
+        qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Indexing complete. Total time:" << m_time.elapsed();
         emitResult();
         return;
     }
@@ -142,9 +142,9 @@ void CollectionIndexingJob::slotPendingIndexed(KJob *job)
 
     const int start = m_time.elapsed();
     const qlonglong indexedItemsCount = m_index.indexedItems(m_collection.id());
-    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Indexed items count took (ms): " << m_time.elapsed() - start;
-    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "In index: " << indexedItemsCount;
-    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Number of Items in collection: " << m_collection.statistics().count() << " In collection " << m_collection.id();
+    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Indexed items count took (ms):" << m_time.elapsed() - start;
+    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "In index:" << indexedItemsCount;
+    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Number of Items in collection:" << m_collection.statistics().count() << "In collection" << m_collection.id();
 
     if (m_collection.statistics().count() == indexedItemsCount) {
         qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Index up to date";
@@ -163,8 +163,8 @@ void CollectionIndexingJob::findUnindexed()
     m_needsIndexing.clear();
     const int start = m_time.elapsed();
     m_index.findIndexed(m_indexedItems, m_collection.id());
-    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Found " << m_indexedItems.size() << " indexed items. Took (ms): " << m_time.elapsed() - start
-                                       << " collection id :" << m_collection.id();
+    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Found" << m_indexedItems.size() << "indexed items. Took (ms):" << m_time.elapsed() - start
+                                       << "collection id:" << m_collection.id();
 
     auto job = new Akonadi::ItemFetchJob(m_collection, this);
     job->fetchScope().fetchFullPayload(false);
@@ -182,7 +182,7 @@ void CollectionIndexingJob::findUnindexed()
 
 void CollectionIndexingJob::slotUnindexedItemsReceived(const Akonadi::Item::List &items)
 {
-    // qCDebug(AKONADI_INDEXER_AGENT_LOG) << "CollectionIndexingJob::slotUnindexedItemsReceived found number items :"<<items.count();
+    // qCDebug(AKONADI_INDEXER_AGENT_LOG) << "CollectionIndexingJob::slotUnindexedItemsReceived found number items:" <<items.count();
     for (const Akonadi::Item &item : items) {
         if (!m_indexedItems.remove(item.id())) {
             m_needsIndexing << item.id();
@@ -192,29 +192,29 @@ void CollectionIndexingJob::slotUnindexedItemsReceived(const Akonadi::Item::List
 
 void CollectionIndexingJob::slotFoundUnindexed(KJob *job)
 {
-    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "CollectionIndexingJob::slotFoundUnindexed :m_needsIndexing.isEmpty() : " << m_needsIndexing.isEmpty()
-                                       << " count :" << m_needsIndexing.count() << " m_reindexingLock :" << m_reindexingLock << "m_collection.id() "
+    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "CollectionIndexingJob::slotFoundUnindexed :m_needsIndexing.isEmpty():" << m_needsIndexing.isEmpty()
+                                       << "count:" << m_needsIndexing.count() << "m_reindexingLock:" << m_reindexingLock << "m_collection.id() "
                                        << m_collection.id();
     if (job->error()) {
-        qCWarning(AKONADI_INDEXER_AGENT_LOG) << "Failed to fetch items: " << job->errorString();
+        qCWarning(AKONADI_INDEXER_AGENT_LOG) << "Failed to fetch items:" << job->errorString();
         setError(KJob::UserDefinedError);
         emitResult();
         return;
     }
 
     if (!m_indexedItems.isEmpty()) {
-        qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Removing no longer existing items: " << m_indexedItems.size();
+        qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Removing no longer existing items:" << m_indexedItems.size();
         m_index.remove(m_indexedItems, m_collection.contentMimeTypes());
     }
     if (!m_needsIndexing.isEmpty() && !m_reindexingLock) {
         m_reindexingLock = true; // Avoid an endless loop
-        qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Found unindexed: " << m_needsIndexing.size();
+        qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Found unindexed:" << m_needsIndexing.size();
         indexItems(m_needsIndexing);
         return;
     }
 
     m_index.commit();
-    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Indexing complete. Total time: " << m_time.elapsed();
+    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Indexing complete. Total time:" << m_time.elapsed();
     emitResult();
 }
 
